@@ -151,11 +151,14 @@ class ModelTorchAdapter(Model):
         self.batchScheduler = None
 
         self.log("LR: %s" % self.learningRate)
+        decay = 0 if self.learningRateDecay is None else self.learningRateDecay
         if self.optimizer == "adams":
-            decay = 0 if self.learningRateDecay is None else self.learningRateDecay
             self.optimizer = optim.Adam(model.parameters(), lr=self.learningRate, weight_decay=decay)
-        if self.optimizer == "nadams":
-            decay = 0 if self.learningRateDecay is None else self.learningRateDecay
+        elif self.optimizer == "sgd":
+            self.optimizer = optim.SGD(model.parameters(), lr=self.learningRate, weight_decay=decay)
+        elif self.optimizer == "nesterov":
+            self.optimizer = optim.SGD(model.parameters(), lr=self.learningRate, weight_decay=decay, nesterov=True)
+        elif self.optimizer == "nadams":
             torch.optim.NAdam(model.parameters(), lr=self.learningRate, momentum_decay=decay)
         elif type(self.optimizer) == str:
             raise Exception("optimizer %s is currently not supported for pytorch implementation" % self.optimizer)
