@@ -37,11 +37,12 @@ class MemmapRecordExporter(DataExporter):
         if tmpPath.is_file():
             tmpPath.unlink()
 
-    def finishStream(self, dataId, options={}):
+    def finishStream(self, dataId, options=None):
+        options = options or {}
         if dataId in self.currentArrayShapes:
             self.finishShape(dataId)
         path = self.getPath(dataId)
-        return shutil.move(path + "-tmp", path)
+        return shutil.move(f"{path}-tmp", path)
 
     def saveFromArrayList(self, dataId, arrayList):
         """fills the array from a list of 2-dimensional arrays"""
@@ -59,7 +60,7 @@ class MemmapRecordExporter(DataExporter):
     def loadTmp(self, dataId):
         shapePath = self.getShapeFilePath(dataId, tmp=True)
         if not Path(shapePath).exists():
-            raise Exception("Shape file not found: %s" % shapePath)
+            raise Exception(f"Shape file not found: {shapePath}")
         self.currentArrayShapes[dataId] = np.load(shapePath, allow_pickle=True)
 
     def saveAndAppendArray(self, dataId, arrayList):
